@@ -363,7 +363,7 @@ def _do_bootstrap_spoke(puppet_account_id, cloudformation, puppet_version):
     logger.info('Finished bootstrap of spoke')
 
 
-def _do_bootstrap(puppet_version):
+def _do_bootstrap(puppet_version, with_manual_approvals):
     click.echo('Starting bootstrap')
     ALL_REGIONS = get_regions(os.environ.get("AWS_DEFAULT_REGION"))
     with betterboto_client.MultiRegionClientContextManager('cloudformation', ALL_REGIONS) as clients:
@@ -422,6 +422,11 @@ def _do_bootstrap(puppet_version):
                     'ParameterValue': str(get_org_iam_role_arn()),
                     'UsePreviousValue': False,
                 },
+                {
+                    'ParameterKey': 'WithManualApprovals',
+                    'ParameterValue': "Yes" if with_manual_approvals else "No",
+                    'UsePreviousValue': False,
+                },
             ],
         }
         cloudformation.create_or_update(**args)
@@ -719,6 +724,4 @@ def run_tasks_for_dry_run(tasks_to_run):
             result.get('notes'),
         ])
     click.echo(table.table)
-
-
     sys.exit(exit_status_codes.get(run_result.status))
