@@ -2,6 +2,7 @@ import os
 
 PREFIX = 'SC-P--'
 BOOTSTRAP_STACK_NAME = "servicecatalog-puppet"
+PIPELINE_NAME = "servicecatalog-puppet-pipeline"
 SERVICE_CATALOG_PUPPET_REPO_NAME = "ServiceCatalogPuppet"
 OUTPUT = "output"
 TEMPLATES = os.path.sep.join([OUTPUT, "templates"])
@@ -22,4 +23,10 @@ DISALLOWED_ATTRIBUTES_FOR_TERMINATED_LAUNCHES = [
     'depends_on',
     'outputs',
     'parameters',
-]
\ No newline at end of file
+]
+
+RESULTS_DIRECTORY = "results"
+
+
+NO_CHANGE = 'NO_CHANGE'
+CHANGE = 'CHANGE'
