@@ -46,9 +46,14 @@ class PuppetTask(luigi.Task):
     @property
     def resources(self):
         resources_for_this_task = {}
-
+        resource_parts = []
         if hasattr(self, 'region'):
-            resources_for_this_task[self.region] = 1
+            resource_parts.append(self.region)
+        if hasattr(self, 'account_id'):
+            resource_parts.append(self.account_id)
+
+        if len(resource_parts) > 0:
+            resources_for_this_task["_".join(resource_parts)] = 1
 
         return resources_for_this_task
 
@@ -90,7 +95,7 @@ class ProvisionProductTask(PuppetTask):
 
     parameters = luigi.ListParameter(default=[])
     ssm_param_inputs = luigi.ListParameter(default=[])
-    dependencies = luigi.ListParameter(default=[])
+    dependencies = luigi.ListParameter(default=[], significant=False)
 
     retry_count = luigi.IntParameter(default=1)
 
@@ -104,11 +109,22 @@ class ProvisionProductTask(PuppetTask):
         ssm_params = {}
         for param_input in self.ssm_param_inputs:
             ssm_params[param_input.get('parameter_name')] = GetSSMParamTask(**param_input)
-
+        dependencies = []
+        for r in self.dependencies:
+            if r.get('status') is not None:
+                if r.get('status') == constants.TERMINATED:
+                    raise Exception("Unsupported")
+                new_r = r.get_wrapped()
+                del new_r['status']
+                dependencies.append(
+                    self.__class__(**new_r)
+                )
+            else:
+                dependencies.append(
+                    self.__class__(**r)
+                )
         return {
-            'dependencies': [
-                self.__class__(**r) for r in self.dependencies
-            ],
+            'dependencies': dependencies,
             'ssm_params': ssm_params
         }
 
@@ -167,7 +183,9 @@ class ProvisionProductTask(PuppetTask):
 
                 for default_cfn_param_name in default_cfn_params.keys():
                     if all_params.get(default_cfn_param_name) is None:
-                        all_params[default_cfn_param_name] = default_cfn_params[default_cfn_param_name]
+                        if default_cfn_params.get(default_cfn_param_name) is not None:
+                            all_params[default_cfn_param_name] = default_cfn_params[default_cfn_param_name]
+
                 if provisioning_artifact_id == self.version_id:
                     logger.info(
                         f"[{self.launch_name}] {self.account_id}:{self.region} :: found previous good provision")
@@ -291,12 +309,18 @@ class ProvisionProductDryRunTask(PuppetTask):
     def requires(self):
         dependencies = []
         for r in self.dependencies:
-            # if hasattr(r, 'status'):
-            #     del r['status']
-            dependencies.append(
-                self.__class__(**r)
-            )
-
+            if r.get('status') is not None:
+                if r.get('status') == constants.TERMINATED:
+                    raise Exception("Unsupported")
+                new_r = r.get_wrapped()
+                del new_r['status']
+                dependencies.append(
+                    self.__class__(**new_r)
+                )
+            else:
+                dependencies.append(
+                    self.__class__(**r)
+                )
         return {
             'dependencies': dependencies,
         }
@@ -344,7 +368,7 @@ class ProvisionProductDryRunTask(PuppetTask):
 
                         if provisioning_artifact_id != self.version_id:
                             self.write_result(
-                                current_version=self.get_current_version(provisioning_artifact_id),
+                                current_version=self.get_current_version(provisioning_artifact_id, service_catalog),
                                 new_version=self.version,
                                 effect=constants.CHANGE,
                                 notes='Version change',
@@ -808,7 +832,12 @@ class ImportIntoSpokeLocalPortfolioTask(PuppetTask):
 
                 logger.info(f"[{self.portfolio}] {self.account_id}:{self.region} :: Copying {hub_product_name}")
                 hub_product_arn = product_view_detail.get('ProductARN')
-                copy_args = {'SourceProductArn': hub_product_arn}
+                copy_args = {
+                    'SourceProductArn': hub_product_arn,
+                    'CopyOptions': [
+                        'CopyTags',
+                    ],
+                }
                 spoke_portfolio = json.loads(self.input().open('r').read())
                 portfolio_id = spoke_portfolio.get("Id")
 
@@ -1024,6 +1053,82 @@ class CreateLaunchRoleConstraintsForPortfolio(PuppetTask):
         )
 
 
+class ResetProvisionedProductOwnerTask(PuppetTask):
+    launch_name = luigi.Parameter()
+    portfolio = luigi.Parameter()
+    product = luigi.Parameter()
+    version = luigi.Parameter()
+
+    product_id = luigi.Parameter()
+    version_id = luigi.Parameter()
+
+    account_id = luigi.Parameter()
+    region = luigi.Parameter()
+    puppet_account_id = luigi.Parameter()
+
+    parameters = luigi.ListParameter(default=[])
+    ssm_param_inputs = luigi.ListParameter(default=[])
+    dependencies = luigi.ListParameter(default=[])
+
+    retry_count = luigi.IntParameter(default=1)
+
+    worker_timeout = luigi.IntParameter(default=0, significant=False)
+
+    ssm_param_outputs = luigi.ListParameter(default=[])
+
+    try_count = 1
+
+    def params_for_results_display(self):
+        return {
+            "launch_name": self.launch_name,
+            "account_id": self.account_id,
+            "region": self.region,
+            "portfolio": self.portfolio,
+            "product": self.product,
+            "version": self.version,
+        }
+
+    def output(self):
+        return luigi.LocalTarget(
+            f"output/ResetProvisionedProductOwnerTask/"
+            f"{self.launch_name}-{self.account_id}-{self.region}-{self.portfolio}-{self.product}-{self.version}.json"
+        )
+
+    def run(self):
+        logger_prefix = f"[{self.launch_name}] {self.account_id}:{self.region}"
+        logger.info(
+            f"{logger_prefix} :: starting ResetProvisionedProductOwnerTask of {self.retry_count}"
+        )
+
+        role = f"arn:aws:iam::{self.account_id}:role/servicecatalog-puppet/PuppetRole"
+        with betterboto_client.CrossAccountClientContextManager(
+                'servicecatalog', role, f'sc-{self.region}-{self.account_id}', region_name=self.region
+        ) as service_catalog:
+            logger.info(
+                f"[{logger_prefix} :: Checking if existing provisioned product exists"
+            )
+            provisioned_product_search_result = service_catalog.search_provisioned_products(
+                AccessLevelFilter={
+                    'Key': 'Account',
+                    'Value': 'self'
+                },
+                Filters={
+                    'SearchQuery': [
+                        f'name:{self.launch_name}',
+                    ]
+                }
+            ).get('ProvisionedProducts', [])
+            if provisioned_product_search_result:
+                provisioned_product_id = provisioned_product_search_result[0].get('Id')
+                logger.info(f"[{logger_prefix} :: Ensuring current provisioned product owner is correct")
+                service_catalog.update_provisioned_product_properties(
+                    ProvisionedProductId=provisioned_product_id,
+                    ProvisionedProductProperties={
+                        'OWNER': f"arn:aws:iam::{self.account_id}:role/servicecatalog-puppet/PuppetRole"
+                    }
+                )
+
+
 def record_event(event_type, task, extra_event_data=None):
     task_type = task.__class__.__name__
     task_params = task.param_kwargs
@@ -1083,5 +1188,5 @@ def on_task_processing_time(task, duration):
 
 
 @luigi.Task.event_handler(luigi.Event.BROKEN_TASK)
-def on_task_broken_task(task):
-    record_event('broken_task', task)
+def on_task_broken_task(task, exception):
+    record_event('broken_task', task, {"exception": exception})
